==> haskell-test-framework-hunit-0.3.0.2-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-2p9ci21xv1JILXjBiIlY85
key: test-framework-hunit-0.3.0.2-2p9ci21xv1JILXjBiIlY85
license: BSD3
maintainer: Haskell Libraries <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
indefinite: False
exposed-modules:
    Test.Framework.Providers.HUnit
abi: 0230f28240d97d7d58fb55c54e0e40ad
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-2p9ci21xv1JILXjBiIlY85
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4 base-4.10.1.0
    extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF
    test-framework-0.8.1.1-G0ulOpUFvAf5rG07vjVYi5
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=55cadea04bfe420efb47c0d18f2d6d9c
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF=74508da8126fd9f76b022516db026445
             test-framework-0.8.1.1-G0ulOpUFvAf5rG07vjVYi5=3d61d84beea082deb995302d84e42868
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-LokxjxgRlv8LQoqKk8xjg6
key: test-framework-hunit-0.3.0.2-LokxjxgRlv8LQoqKk8xjg6
license: BSD3
maintainer: Haskell Libraries <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
indefinite: False
exposed-modules:
    Test.Framework.Providers.HUnit
abi: 1bc74e206831e5e75fe3783b1a7f8366
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-LokxjxgRlv8LQoqKk8xjg6
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4 base-4.10.1.0
    extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF
    test-framework-0.8.2.0-IzHkKvnUOQRBYZlPz9MZzJ
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=55cadea04bfe420efb47c0d18f2d6d9c
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF=74508da8126fd9f76b022516db026445
             test-framework-0.8.2.0-IzHkKvnUOQRBYZlPz9MZzJ=2e15367fce3619b90f90b2fca8c336ad
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
